==> krename-trinity_3.5.13.2.orig.tar.xz: krename-trinity-3.5.13.2/krename/undodialog.h <==
/**************************************************************************
                         undodialog.h  -  description
                             -------------------
    begin                : Mon Mai 27 20:08:19 CEST 2002
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef UNDODIALOG_H
#define UNDODIALOG_H

#include <kdialogbase.h>

class KPushButton;
class KProcess;
class KTextBrowser;
class KURLRequester;
class TQVBoxLayout;
class TQHBoxLayout; 
class TQGridLayout; 
class TQLabel;
class UndoDialog : public KDialogBase
{ 
    Q_OBJECT
  TQ_OBJECT
    public:
        UndoDialog( TQWidget* parent = 0 );
        ~UndoDialog();

        void setUndoScript( const TQString & filename );
    
    public slots:
        void start();
    
    private slots:
        void receive( KProcess*, char* buffer, int len );
        void receiveErr( KProcess*, char* buffer, int len );
        void finished( KProcess* p );
        void enableControls();
        
    private:
        TQLabel* TextLabel1;
        KURLRequester* scriptname;
        TQLabel* TextLabel2;
        KTextBrowser* browser;

    protected:
        TQVBoxLayout* UndoDialogLayout;
};

#endif // UNDODIALOG_H

==> krename-trinity_14.0.6.orig.tar.xz: krename-trinity-14.0.6/krename/undodialog.h <==
/**************************************************************************
                         undodialog.h  -  description
                             -------------------
    begin                : Mon Mai 27 20:08:19 CEST 2002
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef UNDODIALOG_H
#define UNDODIALOG_H

#include <kdialogbase.h>

class KPushButton;
class TDEProcess;
class KTextBrowser;
class KURLRequester;
class TQVBoxLayout;
class TQHBoxLayout; 
class TQGridLayout; 
class TQLabel;
class UndoDialog : public KDialogBase
{ 
    Q_OBJECT
  
    public:
        UndoDialog( TQWidget* parent = 0 );
        ~UndoDialog();

        void setUndoScript( const TQString & filename );
    
    public slots:
        void start();
    
    private slots:
        void receive( TDEProcess*, char* buffer, int len );
        void receiveErr( TDEProcess*, char* buffer, int len );
        void finished( TDEProcess* p );
        void enableControls();
        
    private:
        TQLabel* TextLabel1;
        KURLRequester* scriptname;
        TQLabel* TextLabel2;
        KTextBrowser* browser;

    protected:
        TQVBoxLayout* UndoDialogLayout;
};

#endif // UNDODIALOG_H
